@@ -1,4 +1,4 @@
-# @(#)$Id: CPANTesting.pm 200 2012-11-10 06:04:36Z pjf $
+# @(#)$Id: CPANTesting.pm 201 2012-11-13 11:12:06Z pjf $
 # Bob-Version: 1.6
 
 package CPANTesting;
@@ -21,9 +21,7 @@ sub test_exceptions {
 
    $p->{stop_tests} and return 'CPAN Testing stopped in Build.PL';
 
-   $osname eq q(cygwin)  and return 'Cygwin  OS unsupported';
    $osname eq q(mirbsd)  and return 'Mirbsd  OS unsupported';
-   $osname eq q(mswin32) and return 'MSWin32 OS unsupported';
    $host   eq q(slack64) and return "Stopped Bingos ${host}";
    $host   eq q(falco)   and return "Stopped Bingos ${host}";
    return 0;
